import 'package:petitbac/config/default_game_settings.dart';
import 'package:petitbac/utils/tools.dart';

class GameSettings {
  final int itemsCount;
  final int timerValue;

  GameSettings({
    required this.itemsCount,
    required this.timerValue,
  });

  static int getItemsCountValueFromUnsafe(int itemsCount) {
    if (DefaultGameSettings.allowedItemsCountValues.contains(itemsCount)) {
      return itemsCount;
    }

    return DefaultGameSettings.defaultItemsCountValue;
  }

  static int getTimerValueFromUnsafe(int timerValue) {
    if (DefaultGameSettings.allowedTimerValues.contains(timerValue)) {
      return timerValue;
    }

    return DefaultGameSettings.defaultTimerValue;
  }

  factory GameSettings.createDefault() {
    return GameSettings(
      itemsCount: DefaultGameSettings.defaultItemsCountValue,
      timerValue: DefaultGameSettings.defaultTimerValue,
    );
  }

  void dump() {
    printlog('Game settings: ');
    printlog('  itemsCount: $itemsCount');
    printlog('  timerValue: $timerValue');
  }

  @override
  String toString() {
    return '$GameSettings(${toJson()})';
  }

  Map<String, dynamic>? toJson() {
    return <String, dynamic>{
      'itemsCount': itemsCount,
      'timerValue': timerValue,
    };
  }
}
