import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:petitbac/cubit/game_cubit.dart';
import 'package:petitbac/models/game.dart';
import 'package:petitbac/ui/widgets/helpers/outlined_text_widget.dart';
import 'package:petitbac/utils/color_extensions.dart';

class WidgetLetter extends StatelessWidget {
  const WidgetLetter({super.key});

  @override
  Widget build(BuildContext context) {
    const Color backgroundColor = Colors.orange;
    const double borderWidth = 8.0;

    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;

        final Color borderColor = backgroundColor.darken();

        return Container(
          width: double.maxFinite,
          margin: const EdgeInsets.all(borderWidth),
          padding: const EdgeInsets.all(borderWidth),
          decoration: BoxDecoration(
            color: backgroundColor,
            borderRadius: BorderRadius.circular(borderWidth),
            border: Border.all(
              color: borderColor,
              width: borderWidth,
            ),
          ),
          child: SizedBox(
            height: 100,
            child: TextButton(
              onPressed: () {
                final GameCubit gameCubit = BlocProvider.of<GameCubit>(context);
                gameCubit.pickNewLetter();
              },
              child: OutlinedText(
                text: currentGame.letter.text,
                fontSize: 60,
                textColor: Colors.black,
                outlineColor: Colors.orange.darken(),
              ),
            ),
          ),
        );
      },
    );
  }
}
